@@ -4,12 +4,13 @@ from collections import namedtuple
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric import rsa
-from cryptography.hazmat.primitives.asymmetric.rsa import (
-    RSAPrivateKeyWithSerialization as RSAPrivateKey,
-    RSAPublicKeyWithSerialization as RSAPublicKey,
-)
+from cryptography.hazmat.primitives.asymmetric.rsa import \
+    RSAPrivateKeyWithSerialization as RSAPrivateKey
+from cryptography.hazmat.primitives.asymmetric.rsa import \
+    RSAPublicKeyWithSerialization as RSAPublicKey
 
-KeyPair = namedtuple('KeyPair', ('private', 'public'))
+
+KeyPair = namedtuple("KeyPair", ("private", "public"))
 
 
 def generate_rsa(bits: int = 2048) -> KeyPair:
@@ -22,7 +23,7 @@ def generate_rsa(bits: int = 2048) -> KeyPair:
     private_key = rsa.generate_private_key(
         public_exponent=65537,
         key_size=bits,
-        backend=default_backend()
+        backend=default_backend(),
     )
 
     public_key = private_key.public_key()
@@ -32,11 +33,11 @@ def generate_rsa(bits: int = 2048) -> KeyPair:
 
 def load_private_key(data: str) -> RSAPrivateKey:
     return serialization.load_der_private_key(
-        base64.b64decode(data), None, default_backend()
+        base64.b64decode(data), None, default_backend(),
     )
 
 
 def load_public_key(data: str) -> RSAPublicKey:
     return serialization.load_der_public_key(
-        base64.b64decode(data), default_backend()
+        base64.b64decode(data), default_backend(),
     )
