@@ -1,7 +1,7 @@
 import json
-import sys
-import os
 import logging
+import os
+import sys
 
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import padding
@@ -14,8 +14,8 @@ def main() -> None:
     logging.info("Awaiting JSON on stdin...")
     data = json.load(sys.stdin)
 
-    public_key = load_public_key(data['public'])
-    private_key = load_private_key(data['private'])
+    public_key = load_public_key(data["public"])
+    private_key = load_private_key(data["private"])
 
     payload = os.urandom(1024 * 16)
 
@@ -23,9 +23,9 @@ def main() -> None:
         payload,
         padding.PSS(
             mgf=padding.MGF1(hashes.SHA256()),
-            salt_length=padding.PSS.MAX_LENGTH
+            salt_length=padding.PSS.MAX_LENGTH,
         ),
-        hashes.SHA256()
+        hashes.SHA256(),
     )
 
     logging.info("Signing OK")
@@ -35,9 +35,9 @@ def main() -> None:
         payload,
         padding.PSS(
             mgf=padding.MGF1(hashes.SHA256()),
-            salt_length=padding.PSS.MAX_LENGTH
+            salt_length=padding.PSS.MAX_LENGTH,
         ),
-        hashes.SHA256()
+        hashes.SHA256(),
     )
 
     assert result is None
@@ -45,5 +45,5 @@ def main() -> None:
     logging.info("Verifying OK")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
